@@ -18,7 +18,7 @@ logging.basicConfig(
 
 class DBConnect:
     def __init__(self, db: str, collection: str, home_key='MONGODB_HOST', port_key='MONGODB_PORT'):
-        self.mongo_home = os.environ.get(home_key, None)
+        self.mongo_home = os.environ.get(home_key, '127.0.0.1')
         self.mongo_port = os.environ.get(port_key, 27017)
 
         if not self.mongo_home or not self.mongo_port:
